@@ -8,14 +8,14 @@ that allows you to interact with the stream data in your own application.
 
 
 __title__ = "livestreamer"
-__version__ = "1.4.5"
+__version__ = "1.5"
 __license__ = "Simplified BSD"
 __author__ = "Christopher Rosell"
 __copyright__ = "Copyright 2011-2013 Christopher Rosell"
 __credits__ = ["Christopher Rosell", "Athanasios Oikonomou",
                "Gaspard Jankowiak", "Dominik Dabrowski",
                "Toad King", "Niall McAndrew", "Daniel Wallace",
-               "Sam Edwards"]
+               "Sam Edwards", "John Peterson", "Kacper"]
 
 
 from .exceptions import (PluginError, NoStreamsError,
