@@ -2,7 +2,7 @@ import argparse
 
 from livestreamer import __version__ as livestreamer_version
 
-from .constants import DEFAULT_PLAYER, EXAMPLE_USAGE
+from .constants import EXAMPLE_USAGE
 
 
 class ArgumentParser(argparse.ArgumentParser):
@@ -21,6 +21,7 @@ class ArgumentParser(argparse.ArgumentParser):
         else:
             yield "--%s" % line
 
+list_type = lambda v: [p.strip() for p in v.split(",")]
 
 parser = ArgumentParser(description="CLI program that launches streams from various streaming services in a custom video player",
                         fromfile_prefix_chars="@",
@@ -45,9 +46,9 @@ parser.add_argument("-j", "--json", action="store_true",
                     help="Output JSON instead of the normal text output and disable log output, useful for external scripting")
 
 playeropt = parser.add_argument_group("player options")
-playeropt.add_argument("-p", "--player", metavar="player",
-                       help="Command-line for player, default is '{0}'".format(DEFAULT_PLAYER),
-                       default=DEFAULT_PLAYER)
+playeropt.add_argument("-p", "--player", metavar="command",
+                       help="Player command-line to start, by default Livestreamer will use "
+                            "VLC if it is installed.")
 playeropt.add_argument("-q", "--quiet-player", action="store_true",
                        help="Hide all player console output. This option does nothing since version 1.4.3 since it is now the default behaviour")
 playeropt.add_argument("-v", "--verbose-player", action="store_true",
@@ -79,15 +80,21 @@ streamopt.add_argument("--hds-fragment-buffer", type=int, metavar="fragments",
                              "controls the maximum size of the ringbuffer, default is 10"))
 streamopt.add_argument("--ringbuffer-size", metavar="size", type=int,
                        help=("Specify a maximum size (bytes) for the ringbuffer, default is 32768. "
-                              "Used by RTMP and HLS. Use --hds-fragmentbuffer for HDS"))
+                              "Used by RTMP and HLS. Use --hds-fragment-buffer for HDS"))
 
 pluginopt = parser.add_argument_group("plugin options")
 pluginopt.add_argument("--plugin-dirs", metavar="directory",
                        help="Attempts to load plugins from these directories. Multiple directories can be used by separating them with a semicolon (;)")
-pluginopt.add_argument("--stream-priority", metavar="priorities", default="rtmp,hls,hds,http,akamaihd",
-                       type=lambda v: [p.strip() for p in v.split(",")],
-                       help=("When there are multiple streams with the same name but different streaming types, these priorities will be used. "
-                             "Should be specified as a comma-delimited list, default is rtmp,hls,hds,http,akamaihd"))
+pluginopt.add_argument("--stream-types", "--stream-priority", metavar="types",
+                       default="rtmp,hls,hds,http,akamaihd", type=list_type,
+                       help=("A comma-delimited list of stream types to allow. "
+                             "The order will be used to separate streams when there are "
+                             "multiple streams with the same name and different stream types. "
+                             "Default is rtmp,hls,hds,http,akamaihd"))
+pluginopt.add_argument("--stream-sorting-excludes", metavar="streams",
+                       type=list_type, help="A comma-delimited list of streams to exclude "
+                                            "from the sorting used by best/worst synonyms, "
+                                            "e.g. 1080p+,1080p")
 pluginopt.add_argument("--jtv-cookie", metavar="cookie",
                        help="Specify JustinTV cookie to allow access to subscription channels, e.g. '_twitch_session_id=xxxxxx; persistent=xxxxx;'")
 pluginopt.add_argument("--gomtv-cookie", metavar="cookie",
