@@ -1,5 +1,6 @@
 import json
 import os
+import sys
 import tempfile
 
 from contextlib import contextmanager
@@ -88,4 +89,42 @@ def ignored(*exceptions):
     except exceptions:
         pass
 
-__all__ = ["NamedPipe", "JSONEncoder", "ignored"]
+
+def check_paths(exes, paths):
+    for path in paths:
+        for exe in exes:
+            path = os.path.join(path, exe)
+            if os.path.isfile(path):
+                return path
+
+
+def find_default_player():
+    if "darwin" in sys.platform:
+        paths = os.environ.get("PATH", "").split(":")
+        paths += ["/Applications/VLC.app/Contents/MacOS/"]
+
+        return check_paths(("VLC", "vlc"), paths)
+
+    elif "win32" in sys.platform:
+        exename = "vlc.exe"
+        paths = os.environ.get("PATH", "").split(";")
+        path = check_paths((exename,), paths)
+
+        if not path:
+            subpath = "VideoLAN\\VLC\\"
+            envvars = ("PROGRAMFILES", "PROGRAMFILES(X86)", "PROGRAMW6432")
+            paths = filter(None, (os.environ.get(var) for var in envvars))
+            paths = (os.path.join(p, subpath) for p in paths)
+            path = check_paths((exename,), paths)
+
+        if path:
+            return '"{0}"'.format(path)
+
+    else:
+        paths = os.environ.get("PATH", "").split(":")
+
+        return check_paths(("vlc",), paths)
+
+
+__all__ = ["NamedPipe", "JSONEncoder", "ignored",
+           "find_default_player"]
